"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const BTN_BACK = "$btn-back";
var InputUtil;
(function (InputUtil) {
    function runMultiStepInput(title, steps) {
        return __awaiter(this, void 0, void 0, function* () {
            const ib = vscode.window.createInputBox();
            ib.title = title;
            ib.totalSteps = steps.length;
            ib.ignoreFocusOut = true;
            // Log.d("IB SHOW");
            // ib.show();
            const results = [];
            for (let i = 0; i < steps.length; i++) {
                try {
                    const step = steps[i];
                    const prompt = step.promptGenerator(...results);
                    if (results[i]) {
                        // this step has run before (and user clicked Back) so prefill the previous value
                        step.value = results[i];
                    }
                    const result = yield runInputStep(ib, i, prompt, step);
                    if (result == null) {
                        // quit
                        ib.hide();
                        return undefined;
                    }
                    results[i] = result;
                }
                catch (err) {
                    if (err === BTN_BACK) {
                        i -= 2;
                        continue;
                    }
                    else {
                        // Log.d("IB hide - error");
                        ib.hide();
                        throw err;
                    }
                }
            }
            // Log.d("IB Hide - Done");
            ib.hide();
            return results;
        });
    }
    InputUtil.runMultiStepInput = runMultiStepInput;
    function runInputStep(ib, stepIndex, prompt, step) {
        // ib.title = step.title;
        ib.prompt = prompt;
        ib.placeholder = step.placeholder || "";
        ib.value = step.value || "";
        ib.password = step.password || false;
        ib.step = stepIndex + 1;
        ib.validationMessage = undefined;
        if (stepIndex > 0) {
            ib.buttons = [
                vscode.QuickInputButtons.Back,
            ];
        }
        else {
            ib.buttons = [];
        }
        const disposables = [];
        if (step.validator) {
            disposables.push(ib.onDidChangeValue((value) => {
                if (step.validator) {
                    const invalidMsg = step.validator(value);
                    ib.validationMessage = invalidMsg;
                }
            }));
        }
        // We should only have to show the IB once, but in theia, the IB is hidden after accept
        ib.show();
        return new Promise((resolve, reject) => {
            disposables.push(ib.onDidTriggerButton((_btn) => {
                return reject(BTN_BACK);
            }));
            disposables.push(ib.onDidHide(() => {
                return resolve(undefined);
            }));
            disposables.push(ib.onDidAccept(() => {
                if (ib.value === "" && step.allowEmpty !== true) {
                    ib.validationMessage = "The input cannot be empty.";
                    return;
                }
                // We COULD block acceptance, if there is a validation message, here
                return resolve(ib.value);
            }));
        })
            .finally(() => {
            disposables.forEach((d) => d.dispose());
        });
    }
})(InputUtil || (InputUtil = {}));
exports.default = InputUtil;
//# sourceMappingURL=InputUtil.js.map