"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
class CLICommand {
    constructor(command, options) {
        this.command = command;
        this.cancellable = false;
        this.hasJSONOutput = true;
        this.censorOutput = false;
        if (options) {
            if (options.cancellable != null) {
                this.cancellable = options.cancellable;
            }
            if (options.hasJSONOutput != null) {
                this.hasJSONOutput = options.hasJSONOutput;
            }
            if (options.censorOutput != null) {
                this.censorOutput = options.censorOutput;
            }
        }
    }
}
exports.CLICommand = CLICommand;
var CLICommands;
(function (CLICommands) {
    CLICommands.STATUS = new CLICommand(["status"]);
    CLICommands.UPGRADE = new CLICommand(["upgrade"]);
    // command 'families'
    const PROJECT_CMD = "project";
    const CONNECTIONS_CMD = "connections";
    const TEMPLATES_CMD = "templates";
    // we call them 'sources' cwctl calls them 'repos'
    const SOURCES_CMD = "repos";
    CLICommands.PROJECT = {
        CREATE: new CLICommand([PROJECT_CMD, "create"]),
        SYNC: new CLICommand([PROJECT_CMD, "sync"]),
        BIND: new CLICommand([PROJECT_CMD, "bind"]),
        MANAGE_CONN: new CLICommand([PROJECT_CMD, "connection"]),
    };
    CLICommands.CONNECTIONS = {
        ADD: new CLICommand([CONNECTIONS_CMD, "add"]),
        LIST: new CLICommand([CONNECTIONS_CMD, "list"]),
        REMOVE: new CLICommand([CONNECTIONS_CMD, "remove"]),
        UPDATE: new CLICommand([CONNECTIONS_CMD, "update"], { hasJSONOutput: false })
    };
    CLICommands.TEMPLATE_SOURCES = {
        ADD: new CLICommand([TEMPLATES_CMD, SOURCES_CMD, "add"]),
        LIST: new CLICommand([TEMPLATES_CMD, SOURCES_CMD, "list"]),
        REMOVE: new CLICommand([TEMPLATES_CMD, SOURCES_CMD, "remove"]),
    };
    CLICommands.AUTHENTICATION = {
        KEYRING_UPDATE: new CLICommand(["seckeyring", "update"]),
        // KEYRING_VALIDATE: new CLICommand([ "seckeyring", "validate" ]),
        GET_SECTOKEN: new CLICommand(["sectoken", "get"], { censorOutput: true }),
    };
})(CLICommands = exports.CLICommands || (exports.CLICommands = {}));
//# sourceMappingURL=CLICommands.js.map