"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Requester_1 = require("../project/Requester");
const Logger_1 = require("../../Logger");
var CWEnvironment;
(function (CWEnvironment) {
    CWEnvironment.UNKNOWN_VERSION = "Unknown";
    /**
     * Get the environment data for a Codewind instance at the given url.
     * Separate from normal Requester code because we do not yet have a Connection instance at this point.
     */
    function getEnvData(connection) {
        return __awaiter(this, void 0, void 0, function* () {
            const rawEnv = yield Requester_1.default.getRawEnvironment(connection);
            Logger_1.default.d("Raw env data:", rawEnv);
            const massaged = massageEnv(rawEnv);
            Logger_1.default.i("Massaged ENV data", massaged);
            return massaged;
        });
    }
    CWEnvironment.getEnvData = getEnvData;
    function massageEnv(rawEnv) {
        // const rawWorkspace = rawEnv.workspace_location;
        // if (rawVersion == null) {
        // throw new Error("No version information was provided by Codewind.");
        // }
        // if (!rawWorkspace) {
        // throw new Error("No workspace information was provided by Codewind.");
        // }
        // const workspace = MCUtil.containerPathToFsPath(rawWorkspace);
        const version = rawEnv.codewind_version || CWEnvironment.UNKNOWN_VERSION;
        if (version === CWEnvironment.UNKNOWN_VERSION) {
            Logger_1.default.e(`Environment data was missing Codewind version`);
        }
        const rawSocketNS = rawEnv.socket_namespace || "";
        if (!rawSocketNS) {
            Logger_1.default.e(`Environment data was missing socket namespace`);
        }
        // normalize namespace so it doesn't start with '/'
        const socketNamespace = rawSocketNS.startsWith("/") ? rawSocketNS.substring(1, rawSocketNS.length) : rawSocketNS;
        return {
            // workspace,
            version,
            socketNamespace,
            tektonStatus: rawEnv.tekton_dashboard,
        };
    }
    // const INTERNAL_BUILD_RX: RegExp = /^\d{4}_M\d+_[EI]/;
    /**
     * Parses a version number out of the given env data. If it's a development build, returns Number.MAX_SAFE_INTEGER.
     *
     * **Throws an error** if the version is not supported.
     */
    function getVersionNumber(envData) {
        if (envData.codewind_version === "latest") { // non-nls
            // This means it's being hosted by an internal MC dev.
            // There's nothing we can do here but assume they have all the features we need.
            Logger_1.default.i("Dev version");
            return Number.MAX_SAFE_INTEGER;
        }
        return Number(envData.codewind_version);
        // else if (rawVersion.match(INTERNAL_BUILD_RX) != null) {
        //     Log.i("Internal version");
        //     return Number.MAX_SAFE_INTEGER;
        // }
        // else {
        //     const versionNum = Number(rawVersion);
        //     if (isNaN(versionNum)) {
        //         Log.e("Couldn't convert provided version to Number, version is: " + rawVersion);
        //         throw new Error(Translator.t(STRING_NS, "versionNotRecognized", { rawVersion: rawVersion, requiredVersion: REQUIRED_VERSION_STR}));
        //     }
        //     else if (versionNum < REQUIRED_VERSION) {
        //         Log.e(`Backend version ${versionNum} is too old.`);
        //         throw new Error(Translator.t(STRING_NS, "versionTooOld", { rawVersion: rawVersion, requiredVersion: REQUIRED_VERSION_STR}));
        //     }
        //     return versionNum;
        // }
    }
    CWEnvironment.getVersionNumber = getVersionNumber;
    function getVersionAsString(versionNum) {
        if (versionNum === Number.MAX_SAFE_INTEGER) {
            return "latest";
        }
        else {
            // add this back when we switch back to yy.mm
            /*
            const year = Math.floor(versionNum / 100);
            const month = versionNum % 100;
            return `${year}.${month < 10 ? "0" + month : month}`;
            */
            return versionNum.toString();
        }
    }
    CWEnvironment.getVersionAsString = getVersionAsString;
    /**
     * @returns If the given Connection matches the given environment data for fields the tools are interested in.
     */
    // export function envMatches(connection: Connection, envData: IMCEnvData): boolean {
    //     let newVersionNumber;
    //     try {
    //         newVersionNumber = getVersionNumber(envData);
    //     }
    //     catch (err) {
    //         Log.w(err);
    //         return false;
    //     }
    //     return connection.version === newVersionNumber;
    //         // should check workspace too, but need to consider platform when comparing paths
    //         // more to check once we support ICP
    //         // envData.user_string
    // }
})(CWEnvironment || (CWEnvironment = {}));
exports.default = CWEnvironment;
//# sourceMappingURL=CWEnvironment.js.map