"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../../Logger");
const ConnectionManager_1 = require("./ConnectionManager");
const MCUtil_1 = require("../../MCUtil");
const CLICommandRunner_1 = require("./CLICommandRunner");
const ConnectionOverviewCmd_1 = require("../../command/connection/ConnectionOverviewCmd");
var ConnectionMemento;
(function (ConnectionMemento) {
    /**
     * Save the given connection info using the CLI.
     * @returns The new connection's ID.
     */
    function addConnection(label, url, username) {
        return __awaiter(this, void 0, void 0, function* () {
            if (url instanceof vscode.Uri) {
                url = url.toString();
            }
            Logger_1.default.i(`Saving remote connection ${label} @ ${url}`);
            const addResult = yield CLICommandRunner_1.CLICommandRunner.addConnection(label, url, username);
            const id = addResult.id;
            return id;
        });
    }
    ConnectionMemento.addConnection = addConnection;
    function loadSavedConnections() {
        return __awaiter(this, void 0, void 0, function* () {
            const loaded = (yield CLICommandRunner_1.CLICommandRunner.getRemoteConnections());
            Logger_1.default.i(`Loaded ${loaded.length} saved remote connections`);
            yield Promise.all(loaded.map(loadConnection));
        });
    }
    ConnectionMemento.loadSavedConnections = loadSavedConnections;
    function loadConnection(cliData) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield ConnectionManager_1.default.instance.loadRemoteConnection(cliData);
            }
            catch (err) {
                const errMsg = `Error loading connection ${cliData.label}`;
                Logger_1.default.e(errMsg, err);
                // const retryBtn = "Retry";
                const openSettingsBtn = "Open Connection Settings";
                const rmBtn = "Remove Connection";
                const loadedConn = ConnectionManager_1.default.instance.remoteConnections.find((conn) => conn.id === cliData.id);
                // const btns = [ retryBtn ];
                const btns = [];
                if (loadedConn) {
                    // The load did succeed, there is just a promise with the connection
                    btns.push(openSettingsBtn);
                }
                else {
                    // give the user some way to remove the broken connection
                    btns.push(rmBtn);
                }
                vscode.window.showErrorMessage(`${errMsg}: ${MCUtil_1.default.errToString(err)}`, ...btns)
                    .then((res) => {
                    if (res === rmBtn) {
                        CLICommandRunner_1.CLICommandRunner.removeConnection(cliData.id);
                    }
                    // else if (res === retryBtn) {
                    // loadConnection(cliData);
                    // }
                    // loadedConn will be non-null from the btns condition above
                    else if (res === openSettingsBtn && loadedConn) {
                        ConnectionOverviewCmd_1.default(loadedConn);
                    }
                });
            }
        });
    }
    function save(connectionData) {
        return __awaiter(this, void 0, void 0, function* () {
            return CLICommandRunner_1.CLICommandRunner.updateConnection(connectionData);
        });
    }
    ConnectionMemento.save = save;
})(ConnectionMemento = exports.ConnectionMemento || (exports.ConnectionMemento = {}));
//# sourceMappingURL=ConnectionMemento.js.map