"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const CLICommandRunner_1 = require("./CLICommandRunner");
const Requester_1 = require("../project/Requester");
const CODEWIND_PROJECT_STYLE = "Codewind";
class TemplateSourcesList {
    constructor(connection) {
        this.connection = connection;
        this.hasInitialized = false;
    }
    toString() {
        if (this.templateSources == null) {
            return `Uninitialized TemplateSourcesList`;
        }
        return this.templateSources.toString();
    }
    get(refresh = false) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.templateSources == null || refresh) {
                this.templateSources = yield CLICommandRunner_1.CLICommandRunner.getTemplateSources(this.connection.id, this.hasInitialized);
                this.hasInitialized = true;
            }
            return this.templateSources;
        });
    }
    add(url, name, description) {
        return __awaiter(this, void 0, void 0, function* () {
            this.templateSources = yield CLICommandRunner_1.CLICommandRunner.addTemplateSource(this.connection.id, url, name, description);
            return this.templateSources;
        });
    }
    remove(url) {
        return __awaiter(this, void 0, void 0, function* () {
            this.templateSources = yield CLICommandRunner_1.CLICommandRunner.removeTemplateSource(this.connection.id, url);
            return this.templateSources;
        });
    }
    toggleEnablement(enablement) {
        return __awaiter(this, void 0, void 0, function* () {
            yield Requester_1.default.toggleSourceEnablement(this.connection, enablement);
            return this.get(true);
        });
    }
    // for https://github.com/eclipse/codewind/issues/1469
    hasCodewindSourceEnabled() {
        return __awaiter(this, void 0, void 0, function* () {
            const templateSources = this.templateSources || (yield this.get());
            return templateSources
                .filter((source) => source.enabled)
                .some((source) => source.projectStyles.includes(CODEWIND_PROJECT_STYLE));
        });
    }
}
exports.default = TemplateSourcesList;
//# sourceMappingURL=TemplateSourceList.js.map