"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const CodewindStates_1 = require("./CodewindStates");
const CLICommands_1 = require("../CLICommands");
const TAG_PLACEHOLDER = `$tag$`;
class CLILifecycleCommand extends CLICommands_1.CLICommand {
    constructor(command, userActionName, usesTag, 
    /**
     * The states that the Codewind tree item goes through when this command runs
     */
    transitionStates, cancellable = true, censorOutput = false) {
        super(command, { cancellable, censorOutput, hasJSONOutput: false });
        this.command = command;
        this.userActionName = userActionName;
        this.usesTag = usesTag;
        this.transitionStates = transitionStates;
    }
    getUserActionName(tag) {
        const actionName = this.userActionName;
        if (this.usesTag) {
            return actionName.replace(TAG_PLACEHOLDER, tag);
        }
        return actionName;
    }
}
exports.CLILifecycleCommand = CLILifecycleCommand;
// tslint:disable-next-line: variable-name
exports.CLILifecycleCommands = {
    INSTALL: new CLILifecycleCommand(["install"], `Pulling Codewind ${TAG_PLACEHOLDER} Docker images`, true, {
        during: CodewindStates_1.CodewindStates.INSTALLING,
        onError: CodewindStates_1.CodewindStates.ERR_INSTALLING,
    }, false, true),
    START: new CLILifecycleCommand(["start"], `Starting Codewind ${TAG_PLACEHOLDER}`, true, {
        during: CodewindStates_1.CodewindStates.STARTING,
        onError: CodewindStates_1.CodewindStates.ERR_STARTING,
        after: CodewindStates_1.CodewindStates.STARTED,
    }),
    STOP: new CLILifecycleCommand(["stop-all"], "Stopping Codewind", false, {
        during: CodewindStates_1.CodewindStates.STOPPING,
        onError: CodewindStates_1.CodewindStates.STARTED,
        after: CodewindStates_1.CodewindStates.STOPPED,
    }),
    REMOVE: new CLILifecycleCommand(["remove"], `Removing Codewind ${TAG_PLACEHOLDER} and project images`, true),
};
//# sourceMappingURL=CLILifecycleCommands.js.map