"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const ProjectType_1 = require("./ProjectType");
const Logger_1 = require("../../Logger");
// non-nls-file
var StartModes;
(function (StartModes) {
    StartModes["RUN"] = "run";
    StartModes["DEBUG"] = "debug";
    StartModes["DEBUG_NO_INIT"] = "debugNoInit";
})(StartModes = exports.StartModes || (exports.StartModes = {}));
var ControlCommands;
(function (ControlCommands) {
    ControlCommands["RESTART"] = "restart";
})(ControlCommands = exports.ControlCommands || (exports.ControlCommands = {}));
class ProjectCapabilities {
    constructor(
    // from https://github.com/eclipse/codewind/blob/master/src/pfe/file-watcher/server/src/projects/constants.ts
    startModes, controlCommands) {
        this.startModes = startModes;
        this.controlCommands = controlCommands;
    }
    static getUserFriendlyStartMode(startMode) {
        switch (startMode) {
            case StartModes.RUN:
                return "run";
            case StartModes.DEBUG:
            // For now, debug vs debugNoInit is not exposed to the user. So in both cases it's just "Debug" to them.
            // return "debug (with initial break)";
            case StartModes.DEBUG_NO_INIT:
                return "debug";
            default:
                Logger_1.default.e(`Unknown start mode "${startMode}"!`);
                return "unknown";
        }
    }
    static get allStartModes() {
        return Object.values(StartModes);
    }
    static get allControlCommands() {
        return Object.values(ControlCommands);
    }
    static isDebugMode(startMode) {
        return startMode === StartModes.DEBUG.toString() || startMode === StartModes.DEBUG_NO_INIT.toString();
    }
    static getDefaultStartMode(debug, projectType) {
        if (!debug) {
            return StartModes.RUN;
        }
        if (projectType === ProjectType_1.default.Types.MICROPROFILE) {
            return StartModes.DEBUG;
        }
        return StartModes.DEBUG_NO_INIT;
    }
    get supportsDebug() {
        return this.startModes.some((mode) => ProjectCapabilities.isDebugMode(mode));
    }
    get supportsRestart() {
        return this.controlCommands.includes(ControlCommands.RESTART);
    }
}
exports.default = ProjectCapabilities;
/**
 * In case there's an error with the capabilities, we have this to fall back to.
 * This will enable the actions in the UI, though the backend could still reject the request
 */
ProjectCapabilities.ALL_CAPABILITIES = new ProjectCapabilities(ProjectCapabilities.allStartModes, ProjectCapabilities.allControlCommands);
ProjectCapabilities.NO_CAPABILITIES = new ProjectCapabilities([], []);
//# sourceMappingURL=ProjectCapabilities.js.map