"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const Resources_1 = require("../../constants/Resources");
// import Log from "../../Logger";
class ProjectType {
    constructor(internalType, language, extensionName) {
        this.internalType = internalType;
        this.language = language;
        this.type = ProjectType.getType(internalType, extensionName);
        // this.userFriendlyType = ProjectType.getUserFriendlyType(this.type);
        this.debugType = ProjectType.getDebugType(this.type, language);
        this.icon = ProjectType.getProjectIcon(this.type, language);
    }
    toString() {
        // if (this.extensionName) {
        //     let ufExtension = this.extensionName.toLowerCase();
        //     if (ufExtension.endsWith("extension")) {
        //         ufExtension = ufExtension.substring(0, ufExtension.length - "extension".length);
        //     }
        //     return MCUtil.uppercaseFirstChar(ufExtension);
        // }
        return this.type.toString();
    }
    static getType(internalType, extensionName) {
        if (internalType === this.InternalTypes.MICROPROFILE) {
            return ProjectType.Types.MICROPROFILE;
        }
        else if (internalType === this.InternalTypes.SPRING) {
            return ProjectType.Types.SPRING;
        }
        else if (internalType === this.InternalTypes.NODE) {
            return ProjectType.Types.NODE;
        }
        else if (internalType === this.InternalTypes.SWIFT) {
            return ProjectType.Types.SWIFT;
        }
        else if (internalType === this.InternalTypes.DOCKER) {
            return ProjectType.Types.GENERIC_DOCKER;
        }
        else if (extensionName === this.InternalTypes.EXTENSION_APPSODY) {
            return ProjectType.Types.EXTENSION_APPSODY;
        }
        else if (extensionName === this.InternalTypes.EXTENSION_ODO) {
            return ProjectType.Types.EXTENSION_ODO;
        }
        else {
            // Log.e(`Unrecognized project type ${interalType}`);
            return ProjectType.Types.UNKNOWN;
        }
    }
    /**
     * Get the corresponding VSCode debug configuration "type" value.
     * Returns undefined if we don't have any project types that use the language and support debug.
     */
    static getDebugType(type, language) {
        switch (type) {
            case ProjectType.Types.MICROPROFILE:
            case ProjectType.Types.SPRING:
                return this.DebugTypes.JAVA;
            case ProjectType.Types.NODE:
                return this.DebugTypes.NODE;
            case ProjectType.Types.EXTENSION_APPSODY:
                // For extension types, we use the language to determine debug type
                const lang = language.toLowerCase();
                if (lang === this.Languages.JAVA) {
                    return this.DebugTypes.JAVA;
                }
                else if (lang === this.Languages.NODE) {
                    return this.DebugTypes.NODE;
                }
            default:
                return undefined;
        }
    }
    static getProjectIcon(type, language) {
        switch (language.toLowerCase()) {
            case this.Languages.JAVA:
                if (type === ProjectType.Types.MICROPROFILE) {
                    return Resources_1.default.Icons.Microprofile;
                }
                else if (type === ProjectType.Types.SPRING) {
                    return Resources_1.default.Icons.Spring;
                }
                else {
                    return Resources_1.default.Icons.Java;
                }
            case this.Languages.NODE:
            case "javascript":
            case "js":
                return Resources_1.default.Icons.NodeJS;
            case this.Languages.SWIFT:
                return Resources_1.default.Icons.Swift;
            case this.Languages.PYTHON:
                return Resources_1.default.Icons.Python;
            case this.Languages.GO:
                return Resources_1.default.Icons.Go;
            default:
                return Resources_1.default.Icons.Generic;
        }
    }
    /*
    private static getUserFriendlyType(type: ProjectType.Types): string {
        // For docker projects, return the language
        /*
        if (type === ProjectType.Types.GENERIC_DOCKER && language != null) {
            return uppercaseFirstChar(language);
        }

        // For all other types, the enum's string value is user-friendly
        return type.toString();
    }*/
    get providesBuildLog() {
        return !ProjectType.PROJECTS_WITHOUT_BUILDLOGS.includes(this.type);
    }
    get canInjectMetrics() {
        // This should be the job of the capabilities API
        return [
            ProjectType.InternalTypes.MICROPROFILE,
            ProjectType.InternalTypes.NODE,
            ProjectType.InternalTypes.SPRING
        ].includes(this.internalType);
    }
    get alwaysHasAppMonitor() {
        // This should be the job of the capabilities API
        return [
            ProjectType.Languages.JAVA,
            ProjectType.Languages.NODE,
        ]
            .map((lang) => lang.toString().toLowerCase())
            .includes(this.language.toLowerCase());
    }
    get isExtensionType() {
        return [
            ProjectType.Types.EXTENSION_APPSODY,
            ProjectType.Types.EXTENSION_ODO,
        ].includes(this.type);
    }
}
exports.ProjectType = ProjectType;
(function (ProjectType) {
    /*
     * These are the project types as exposed to the user. String value must be user-friendly.
     */
    let Types;
    (function (Types) {
        Types["MICROPROFILE"] = "Microprofile";
        Types["SPRING"] = "Spring";
        Types["NODE"] = "Node.js";
        Types["SWIFT"] = "Swift";
        Types["GENERIC_DOCKER"] = "Docker";
        Types["EXTENSION_APPSODY"] = "Appsody";
        Types["EXTENSION_ODO"] = "OpenShift Do";
        Types["UNKNOWN"] = "Unknown";
    })(Types = ProjectType.Types || (ProjectType.Types = {}));
    // non-nls-section-start
    /**
     * Possible values of the "projectType" or "buildType" internal attribute
     */
    let InternalTypes;
    (function (InternalTypes) {
        InternalTypes["MICROPROFILE"] = "liberty";
        InternalTypes["SPRING"] = "spring";
        InternalTypes["NODE"] = "nodejs";
        InternalTypes["SWIFT"] = "swift";
        InternalTypes["DOCKER"] = "docker";
        InternalTypes["EXTENSION_APPSODY"] = "appsodyExtension";
        InternalTypes["EXTENSION_ODO"] = "odoExtension";
    })(InternalTypes = ProjectType.InternalTypes || (ProjectType.InternalTypes = {}));
    /**
     * Some possible values of the "language" internal attribute, for which we have special treatment such as nicer icons.
     * Language can be user-determined so this is not a complete list
     */
    let Languages;
    (function (Languages) {
        Languages["JAVA"] = "java";
        Languages["NODE"] = "nodejs";
        Languages["SWIFT"] = "swift";
        Languages["PYTHON"] = "python";
        Languages["GO"] = "go";
    })(Languages = ProjectType.Languages || (ProjectType.Languages = {}));
    /**
     * VSCode debug types, used as the "type" attribute in a debug launch.
     */
    let DebugTypes;
    (function (DebugTypes) {
        DebugTypes["JAVA"] = "java";
        DebugTypes["NODE"] = "node";
    })(DebugTypes = ProjectType.DebugTypes || (ProjectType.DebugTypes = {}));
    // non-nls-section-end
    ProjectType.PROJECTS_WITHOUT_BUILDLOGS = [
        ProjectType.Types.NODE
    ];
})(ProjectType = exports.ProjectType || (exports.ProjectType = {}));
exports.default = ProjectType;
//# sourceMappingURL=ProjectType.js.map