"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2020 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Commands_1 = require("../constants/Commands");
const translator_1 = require("../constants/strings/translator");
const StringNamespaces_1 = require("../constants/strings/StringNamespaces");
const Logger_1 = require("../Logger");
const MCUtil_1 = require("../MCUtil");
const RestartProjectCmd_1 = require("./project/RestartProjectCmd");
const OpenAppCmd_1 = require("./project/OpenAppCmd");
const RequestBuildCmd_1 = require("./project/RequestBuildCmd");
const ToggleEnablementCmd_1 = require("./project/ToggleEnablementCmd");
const ProjectOverviewCmd_1 = require("./project/ProjectOverviewCmd");
const ToggleAutoBuildCmd_1 = require("./project/ToggleAutoBuildCmd");
const OpenAppMonitor_1 = require("./project/OpenAppMonitor");
const RefreshConnectionCmd_1 = require("./connection/RefreshConnectionCmd");
const ManageLogsCmd_1 = require("./project/ManageLogsCmd");
const CreateUserProjectCmd_1 = require("./connection/CreateUserProjectCmd");
const BindProjectCmd_1 = require("./connection/BindProjectCmd");
const OpenPerfDashboard_1 = require("./project/OpenPerfDashboard");
const StartCodewindCmd_1 = require("./StartCodewindCmd");
const StopCodewindCmd_1 = require("./StopCodewindCmd");
const RemoveImagesCmd_1 = require("./RemoveImagesCmd");
const Connection_1 = require("../codewind/connection/Connection");
const ProjectState_1 = require("../codewind/project/ProjectState");
const AttachDebuggerCmd_1 = require("./project/AttachDebuggerCmd");
const ContainerShellCmd_1 = require("./project/ContainerShellCmd");
const RemoveProjectCmd_1 = require("./project/RemoveProjectCmd");
const AddToWorkspaceCmd_1 = require("./project/AddToWorkspaceCmd");
const ManageSourcesCmd_1 = require("./connection/ManageSourcesCmd");
const OpenTektonCmd_1 = require("./connection/OpenTektonCmd");
const ConnectionManager_1 = require("../codewind/connection/ConnectionManager");
const NewConnectionCmd_1 = require("./connection/NewConnectionCmd");
const LocalCodewindManager_1 = require("../codewind/connection/local/LocalCodewindManager");
const ConnectionOverviewCmd_1 = require("./connection/ConnectionOverviewCmd");
const RemoveConnectionCmd_1 = require("./connection/RemoveConnectionCmd");
const ToggleConnectionEnablement_1 = require("./connection/ToggleConnectionEnablement");
const ManageRegistriesCmd_1 = require("./connection/ManageRegistriesCmd");
const ToggleAutoInjectMetrics_1 = require("./project/ToggleAutoInjectMetrics");
const ChangeProjectConnectionCmd_1 = require("./project/ChangeProjectConnectionCmd");
function createCommands() {
    // Register our commands here
    // The first parameter must match the command ID as declared in package.json
    // the second parameter is the callback function, which is passed the user's selection, which is either:
    // - undefined (if run from command palette)
    // - or the user's selected TreeView object (if run from the context menu) -> IE either a Project or Connection
    return [
        vscode.commands.registerCommand(Commands_1.default.START_LOCAL_CODEWIND, StartCodewindCmd_1.default),
        vscode.commands.registerCommand(Commands_1.default.STOP_LOCAL_CODEWIND, StopCodewindCmd_1.default),
        vscode.commands.registerCommand(Commands_1.default.REMOVE_LOCAL_IMAGES, RemoveImagesCmd_1.default),
        // the separator is just for display purposes and has no command bound to it
        vscode.commands.registerCommand(Commands_1.default.SEPARATOR, () => { }),
        vscode.commands.registerCommand(Commands_1.default.NEW_CONNECTION, NewConnectionCmd_1.newRemoteConnectionCmd),
        // For connection commands, make sure the connected-ness requirement matches the context enablement regex used in package.json
        registerConnectionCommand(Commands_1.default.REMOVE_CONNECTION, RemoveConnectionCmd_1.default, undefined, false, true),
        registerConnectionCommand(Commands_1.default.ENABLE_CONNECTION, ToggleConnectionEnablement_1.default, true, false, true),
        registerConnectionCommand(Commands_1.default.DISABLE_CONNECTION, ToggleConnectionEnablement_1.default, false, false, true),
        registerConnectionCommand(Commands_1.default.REFRESH_CONNECTION, RefreshConnectionCmd_1.default, undefined, false, false),
        registerConnectionCommand(Commands_1.default.CREATE_PROJECT, CreateUserProjectCmd_1.default, undefined, true, false),
        registerConnectionCommand(Commands_1.default.BIND_PROJECT, BindProjectCmd_1.default, undefined, true, false),
        registerConnectionCommand(Commands_1.default.CONNECTION_OVERVIEW, ConnectionOverviewCmd_1.default, undefined, false, true),
        registerConnectionCommand(Commands_1.default.MANAGE_TEMPLATE_SOURCES, ManageSourcesCmd_1.default, undefined, true, false),
        registerConnectionCommand(Commands_1.default.MANAGE_REGISTRIES, ManageRegistriesCmd_1.default, undefined, true, false),
        registerConnectionCommand(Commands_1.default.OPEN_TEKTON, OpenTektonCmd_1.openTektonDashboard, undefined, true, false),
        registerProjectCommand(Commands_1.default.PROJECT_OVERVIEW, ProjectOverviewCmd_1.default, undefined, ProjectState_1.default.getAllAppStates()),
        registerProjectCommand(Commands_1.default.OPEN_APP, OpenAppCmd_1.default, undefined, ProjectState_1.default.getStartedOrStartingStates()),
        registerProjectCommand(Commands_1.default.CONTAINER_SHELL, ContainerShellCmd_1.default, undefined, ProjectState_1.default.getStartedOrStartingStates()),
        registerProjectCommand(Commands_1.default.ADD_PROJECT_TO_WS, AddToWorkspaceCmd_1.default, undefined, ProjectState_1.default.getAllAppStates()),
        registerProjectCommand(Commands_1.default.REQUEST_BUILD, RequestBuildCmd_1.default, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.TOGGLE_AUTOBUILD, ToggleAutoBuildCmd_1.default, undefined, ProjectState_1.default.getEnabledStates()),
        // Enable and disable AB are the same as Toggle AB - they are just presented to the user differently.
        registerProjectCommand(Commands_1.default.ENABLE_AUTOBUILD, ToggleAutoBuildCmd_1.default, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.DISABLE_AUTOBUILD, ToggleAutoBuildCmd_1.default, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.ATTACH_DEBUGGER, AttachDebuggerCmd_1.default, undefined, ProjectState_1.default.getDebuggableStates()),
        registerProjectCommand(Commands_1.default.RESTART_RUN, RestartProjectCmd_1.default, false, ProjectState_1.default.getStartedOrStartingStates()),
        registerProjectCommand(Commands_1.default.RESTART_DEBUG, RestartProjectCmd_1.default, true, ProjectState_1.default.getStartedOrStartingStates()),
        registerProjectCommand(Commands_1.default.MANAGE_LOGS, ManageLogsCmd_1.manageLogs, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.SHOW_ALL_LOGS, ManageLogsCmd_1.showAllLogs, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.HIDE_ALL_LOGS, ManageLogsCmd_1.hideAllLogs, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.ENABLE_PROJECT, ToggleEnablementCmd_1.default, undefined, [ProjectState_1.default.AppStates.DISABLED]),
        registerProjectCommand(Commands_1.default.DISABLE_PROJECT, ToggleEnablementCmd_1.default, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.REMOVE_PROJECT, RemoveProjectCmd_1.default, undefined, ProjectState_1.default.getAllAppStates()),
        registerProjectCommand(Commands_1.default.CHANGE_PROJECT_CONNECTION, ChangeProjectConnectionCmd_1.default, undefined, ProjectState_1.default.getAllAppStates()),
        registerProjectCommand(Commands_1.default.OPEN_APP_MONITOR, OpenAppMonitor_1.default, undefined, ProjectState_1.default.getStartedOrStartingStates()),
        registerProjectCommand(Commands_1.default.OPEN_PERF_DASHBOARD, OpenPerfDashboard_1.default, undefined, ProjectState_1.default.getStartedOrStartingStates()),
        registerProjectCommand(Commands_1.default.TOGGLE_INJECT_METRICS, ToggleAutoInjectMetrics_1.default, undefined, ProjectState_1.default.getEnabledStates()),
        // Enable and disable "Inject Metrics" are the same as Toggle "Inject Metrics" - they are just presented to the user differently.
        registerProjectCommand(Commands_1.default.ENABLE_INJECT_METRICS, ToggleAutoInjectMetrics_1.default, undefined, ProjectState_1.default.getEnabledStates()),
        registerProjectCommand(Commands_1.default.DISABLE_INJECT_METRICS, ToggleAutoInjectMetrics_1.default, undefined, ProjectState_1.default.getEnabledStates()),
    ];
}
exports.createCommands = createCommands;
/**
 * Register a command that runs on Project objects.
 *
 * The type argument(s) must be the types of the arguments (other than the first) to be passed to the executor.
 * Note the compiler does not check that these actually match the function signature.
 *
 * @param id - The command ID
 * @param executor - The function that runs the command
 * @param params - Parameters to pass to the executor function
 * @param acceptableStates - If the user runs the command through the command palette,
 *      the list of projects presented to choose from is filtered to projects in these states
 */
function registerProjectCommand(id, executor, params, acceptableStates) {
    return vscode.commands.registerCommand(id, (selection) => __awaiter(this, void 0, void 0, function* () {
        if (!selection) {
            selection = yield promptForProject(acceptableStates);
            if (!selection) {
                return;
            }
        }
        try {
            executor(selection, params);
        }
        catch (err) {
            Logger_1.default.e(`Unexpected error running command ${id}`, err);
            vscode.window.showErrorMessage(`Error running command ${id}: on project ${selection.name} ${MCUtil_1.default.errToString(err)}`);
        }
    }));
}
/**
 * Register a command that runs on Connection objects.
 *
 * The type argument(s) must be the types of the arguments (other than the first) to be passed to the executor.
 * Note the compiler does not check that these actually match the function signature.
 *
 * @param id - The command ID
 * @param executor - The function that runs the command
 * @param params - Parameters to pass to the executor function
 * @param connectedOnly - If the user runs the command through the command palette,
 *      only currently connected connections will be presented as options
 */
function registerConnectionCommand(id, executor, params, connectedOnly, remoteOnly) {
    // The selection can be a TreeItem if the command was run from the tree root's context menu,
    // a Connection if the command was run from a Connection's context menu,
    // or undefined if the command palette
    return vscode.commands.registerCommand(id, (selection) => __awaiter(this, void 0, void 0, function* () {
        if (selection instanceof LocalCodewindManager_1.default) {
            selection = LocalCodewindManager_1.default.instance.localConnection;
        }
        if (!(selection instanceof Connection_1.default)) {
            selection = yield promptForConnection(connectedOnly, remoteOnly);
            // if (selection == null) {
            if (!(selection instanceof Connection_1.default)) {
                return;
            }
        }
        try {
            executor(selection, params);
        }
        catch (err) {
            Logger_1.default.e(`Unexpected error running command ${id}`, err);
            vscode.window.showErrorMessage(`Error running command ${id}: on connection ${selection.url} ${MCUtil_1.default.errToString(err)}`);
        }
    }));
}
/**
 * If the user runs a Project command through the Command Palette, have them pick the project to run the cmd on
 * @param acceptableStates - If at least one state is passed, only projects in one of these states will be presented to the user.
 */
function promptForProject(acceptableStates) {
    return __awaiter(this, void 0, void 0, function* () {
        // for now, assume if they want Started, they also accept Debugging. This may change.
        if (acceptableStates.includes(ProjectState_1.default.AppStates.STARTED) && !acceptableStates.includes(ProjectState_1.default.AppStates.DEBUGGING)) {
            acceptableStates.push(ProjectState_1.default.AppStates.DEBUGGING);
        }
        // same for Starting / Starting - Debug
        if (acceptableStates.includes(ProjectState_1.default.AppStates.STARTING) && !acceptableStates.includes(ProjectState_1.default.AppStates.DEBUG_STARTING)) {
            acceptableStates.push(ProjectState_1.default.AppStates.DEBUG_STARTING);
        }
        const choices = (yield ConnectionManager_1.default.instance.allProjects)
            .filter((p) => acceptableStates.includes(p.state.appState));
        // If no choices are available, show a popup message
        if (choices.length === 0) {
            showNoValidProjectsMsg(acceptableStates);
            return undefined;
        }
        return /* await */ vscode.window.showQuickPick(choices, {
            canPickMany: false,
            placeHolder: "Select a project to run this command on",
        });
    });
}
const STRING_NS = StringNamespaces_1.default.CMD_RES_PROMPT;
function showNoValidProjectsMsg(acceptableStates) {
    const statesSpecified = acceptableStates.length !== 0;
    let noValidResourcesMsg;
    let requiredStatesStr = "";
    if (statesSpecified) {
        // this builds something like "Starting - Debug or Debugging", to represent the project states this command can run on.
        const sep = translator_1.default.t(StringNamespaces_1.default.DEFAULT, "statesSeparator");
        requiredStatesStr += acceptableStates.map((state) => state.toString()).join(sep);
        noValidResourcesMsg = translator_1.default.t(STRING_NS, "noProjToRunOnWithStates", { states: requiredStatesStr });
    }
    else {
        noValidResourcesMsg = translator_1.default.t(STRING_NS, "noProjToRunOn");
    }
    vscode.window.showWarningMessage(noValidResourcesMsg);
}
/**
 * If the user runs a Connection command through the Command Palette, have them pick the connection to run the cmd on
 * @connectedOnly Only prompt the user with Connected connections
 */
function promptForConnection(connectedOnly, remoteOnly) {
    return __awaiter(this, void 0, void 0, function* () {
        if (ConnectionManager_1.default.instance.connections.length === 1) {
            const onlyConnection = ConnectionManager_1.default.instance.connections[0];
            if (onlyConnection.isConnected || !connectedOnly) {
                return onlyConnection;
            }
        }
        const choices = ConnectionManager_1.default.instance.connections.filter((conn) => {
            if (connectedOnly && !conn.isConnected) {
                return false;
            }
            if (remoteOnly && !conn.isRemote) {
                return false;
            }
            return true;
        });
        if (choices.length === 0) {
            if (global.isTheia) {
                vscode.window.showWarningMessage(`Codewind has not yet started. Wait for the Codewind pod to come up before running this command.`);
            }
            else {
                const startCwBtn = "Start Local Codewind";
                const newConnectionBtn = "New Connection";
                vscode.window.showWarningMessage(translator_1.default.t(STRING_NS, "noConnToRunOn"), startCwBtn, newConnectionBtn)
                    .then((res) => {
                    if (res === startCwBtn) {
                        StartCodewindCmd_1.default(true);
                    }
                    else if (res === newConnectionBtn) {
                        NewConnectionCmd_1.newRemoteConnectionCmd();
                    }
                });
            }
            return undefined;
        }
        return /* await */ vscode.window.showQuickPick(choices, {
            canPickMany: false,
            placeHolder: "Select a connection to run this command on",
        });
    });
}
//# sourceMappingURL=CommandUtil.js.map