"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const CLIWrapper_1 = require("../codewind/connection/CLIWrapper");
const Logger_1 = require("../Logger");
const MCUtil_1 = require("../MCUtil");
const StringNamespaces_1 = require("../constants/strings/StringNamespaces");
const translator_1 = require("../constants/strings/translator");
const LocalCodewindManager_1 = require("../codewind/connection/local/LocalCodewindManager");
const CLILifecycleWrapper_1 = require("../codewind/connection/local/CLILifecycleWrapper");
const STRING_NS = StringNamespaces_1.default.STARTUP;
function removeImagesCmd() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            if (LocalCodewindManager_1.default.instance.isStarted) {
                vscode.window.showWarningMessage(translator_1.default.t(STRING_NS, "removeImagesBlockedStillRunning"));
                return;
            }
            const positiveResponse = "Remove Images";
            const response = yield vscode.window.showWarningMessage(translator_1.default.t(STRING_NS, "removeImagesModalWarning"), { modal: true }, positiveResponse);
            if (response !== positiveResponse) {
                return;
            }
            Logger_1.default.i("Removing Codewind images");
            yield CLILifecycleWrapper_1.default.removeAllImages();
        }
        catch (err) {
            if (!CLIWrapper_1.default.isCancellation(err)) {
                Logger_1.default.e("Error removing images", err);
                vscode.window.showErrorMessage("Error removing images: " + MCUtil_1.default.errToString(err));
            }
        }
    });
}
exports.default = removeImagesCmd;
//# sourceMappingURL=RemoveImagesCmd.js.map