"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../Logger");
const LocalCodewindManager_1 = require("../codewind/connection/local/LocalCodewindManager");
const CLILifecycleWrapper_1 = require("../codewind/connection/local/CLILifecycleWrapper");
const MCUtil_1 = require("../MCUtil");
const CLIWrapper_1 = require("../codewind/connection/CLIWrapper");
/**
 *
 * @param start
 *      Set to false to just connect to Codewind if it's already started, and do nothing if it's stopped.
 *      This is so that we can connect if it's already started on activation, while requiring user interaction to start the containers.
 */
function connectLocalCodewindCmd(start = true) {
    return __awaiter(this, void 0, void 0, function* () {
        Logger_1.default.i("Connect Local Codewind Cmd");
        try {
            if (global.isTheia) {
                yield LocalCodewindManager_1.default.instance.waitForCodewindToStartTheia();
                return;
            }
            const startedStatus = yield CLILifecycleWrapper_1.default.getCodewindStartedStatus();
            if (startedStatus === "started-correct-version") {
                const url = yield CLILifecycleWrapper_1.default.getCodewindUrl();
                Logger_1.default.i("The correct version of local Codewind is already started at " + url);
                if (url == null) {
                    vscode.window.showErrorMessage("Could not determine URL of started Codewind instance");
                    return;
                }
                yield LocalCodewindManager_1.default.instance.connect(url);
                return;
            }
            else if (startedStatus === "started-wrong-version") {
                // Force start to prompt the user to upgrade; they can reject it if they like.
                start = true;
            }
            if (start) {
                yield LocalCodewindManager_1.default.instance.startCodewind();
            }
        }
        catch (err) {
            Logger_1.default.e("StartCodewindCmd error", err);
            CLIWrapper_1.default.showCLIError(`Error initializing Codewind: ${MCUtil_1.default.errToString(err)}`);
        }
    });
}
exports.default = connectLocalCodewindCmd;
//# sourceMappingURL=StartCodewindCmd.js.map