"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../../Logger");
const MCUtil_1 = require("../../MCUtil");
const RegistriesPageWrapper_1 = require("../webview/RegistriesPageWrapper");
function manageRegistriesCmd(connection) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!connection.isKubeConnection) {
            vscode.window.showWarningMessage(`The local connection does not use container image registries.`);
            return;
        }
        try {
            if (connection.registriesPage) {
                // Show existing page
                connection.registriesPage.reveal();
                return;
            }
            // tslint:disable-next-line: no-unused-expression
            new RegistriesPageWrapper_1.RegistriesPageWrapper(connection);
        }
        catch (err) {
            const errMsg = `Error opening Image Registries page:`;
            vscode.window.showErrorMessage(`${errMsg} ${MCUtil_1.default.errToString(err)}`);
            Logger_1.default.e(errMsg, err);
        }
    });
}
exports.default = manageRegistriesCmd;
//# sourceMappingURL=ManageRegistriesCmd.js.map