"use strict";
/*******************************************************************************
 * Copyright (c) 2019, 2020 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const MCUtil_1 = require("../../MCUtil");
const Logger_1 = require("../../Logger");
const Commands_1 = require("../../constants/Commands");
const CWEnvironment_1 = require("../../codewind/connection/CWEnvironment");
function openTektonDashboard(connection) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!connection.isKubeConnection) {
            vscode.window.showWarningMessage(`Pipelines are only available on Kubernetes.`);
            return;
        }
        try {
            const tektonStatus = (yield CWEnvironment_1.default.getEnvData(connection)).tektonStatus;
            if (!tektonStatus.status || !tektonStatus.url) {
                if (tektonStatus.message === "not-installed") {
                    vscode.window.showErrorMessage("Tekton Dashboard does not appear to be installed on this cluster. " +
                        "Please install Tekton Dashboard on your cluster.");
                }
                else {
                    vscode.window.showErrorMessage("There was an error detecting the Tekton Dashboard installation on this cluster. " +
                        "Please install or re-install Tekton Dashboard on your cluster.");
                }
                return;
            }
            // TODO is it always http?
            // The 'url' is just the authority component
            const asUri = vscode.Uri.parse(`http://${tektonStatus.url}`);
            const isGoodUrl = !!(asUri.authority);
            if (!isGoodUrl) {
                vscode.window.showErrorMessage(`The Tekton Dashboard URL "${tektonStatus.url}" does not appear to be valid`);
                return;
            }
            // we did it
            vscode.commands.executeCommand(Commands_1.default.VSC_OPEN, asUri);
        }
        catch (err) {
            Logger_1.default.e("Error doing openTektonCmd", err);
            vscode.window.showErrorMessage(MCUtil_1.default.errToString(err));
        }
    });
}
exports.openTektonDashboard = openTektonDashboard;
//# sourceMappingURL=OpenTektonCmd.js.map