"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const LocalCodewindManager_1 = require("../../codewind/connection/local/LocalCodewindManager");
const MCUtil_1 = require("../../MCUtil");
const Logger_1 = require("../../Logger");
function refreshConnectionCmd(connection) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            if (!connection.isRemote) {
                // If local was restarted outside of the IDE, the IDE will not pick up the new URL until a manual refresh.
                // In Theia this has no effect
                const localHasChanged = yield LocalCodewindManager_1.default.instance.refresh();
                if (localHasChanged) {
                    vscode.window.showInformationMessage(`Reconnected to Local Codewind`);
                    // We don't have to do the projects update in this case because the connection was recreated
                    return;
                }
            }
            yield vscode.window.withProgress({
                cancellable: false,
                location: vscode.ProgressLocation.Notification,
                title: `Refreshing ${connection.label}...`,
            }, () => {
                return connection.refresh();
            });
        }
        catch (err) {
            const errMsg = `Error refreshing ${connection.label}`;
            vscode.window.showErrorMessage(`${errMsg}: ${MCUtil_1.default.errToString(err)}`);
            Logger_1.default.e(errMsg, err);
        }
    });
}
exports.default = refreshConnectionCmd;
//# sourceMappingURL=RefreshConnectionCmd.js.map