"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../../Logger");
const ConnectionManager_1 = require("../../codewind/connection/ConnectionManager");
const LocalCodewindManager_1 = require("../../codewind/connection/local/LocalCodewindManager");
const StopCodewindCmd_1 = require("../StopCodewindCmd");
const MCUtil_1 = require("../../MCUtil");
function removeConnectionCmd(connection) {
    return __awaiter(this, void 0, void 0, function* () {
        if (connection === LocalCodewindManager_1.default.instance.localConnection) {
            const stopCodewindBtn = "Stop Local Codewind";
            vscode.window.showWarningMessage("You cannot remove the local connection. Stop Codewind instead.", stopCodewindBtn)
                .then((res) => {
                if (res === stopCodewindBtn) {
                    StopCodewindCmd_1.default();
                }
            });
            return false;
        }
        const yesBtn = "Yes";
        const confirm = yield vscode.window.showWarningMessage(`Are you sure you want to remove ${connection.label}?`, { modal: true }, yesBtn);
        if (confirm !== yesBtn) {
            return false;
        }
        Logger_1.default.i("Removing connection " + connection.url);
        try {
            yield ConnectionManager_1.default.instance.removeConnection(connection);
            return true;
        }
        catch (err) {
            const errMsg = `Error removing ${connection.label}`;
            Logger_1.default.e(errMsg, err);
            vscode.window.showErrorMessage(`${errMsg}: ${MCUtil_1.default.errToString(errMsg)}`);
            return false;
        }
    });
}
exports.default = removeConnectionCmd;
//# sourceMappingURL=RemoveConnectionCmd.js.map