"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../../Logger");
const MCUtil_1 = require("../../MCUtil");
const ConnectionOverviewCmd_1 = require("./ConnectionOverviewCmd");
const RefreshConnectionCmd_1 = require("./RefreshConnectionCmd");
function toggleConnectionEnablementCmd(connection_, enable) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!connection_.isRemote) {
            Logger_1.default.e("Cannot toggle enablement for the local connection");
            return;
        }
        const connection = connection_;
        if (connection.enabled) {
            if (enable) {
                vscode.window.showWarningMessage(`${connection.label} is already enabled.`);
                return;
            }
        }
        else if (!enable) {
            vscode.window.showWarningMessage(`${connection.label} is already disabled.`);
            return;
        }
        Logger_1.default.i(`${enable ? "Enable" : "Disable"} ${connection.label}`);
        try {
            yield vscode.window.withProgress({
                cancellable: false,
                location: vscode.ProgressLocation.Notification,
                title: `${enable ? "Connecting to" : "Disconnecting from"} ${connection.label}...`
            }, () => __awaiter(this, void 0, void 0, function* () {
                yield (enable ? connection.enable() : connection.disable());
            }));
        }
        catch (err) {
            const errMsg = `Failed to ${enable ? "connect to" : "disconnect from"} ${connection.label}: ${MCUtil_1.default.errToString(err)}`;
            Logger_1.default.e(errMsg, err);
            const openConnSettingsBtn = "Open Connection Settings";
            const refreshBtn = "Refresh";
            vscode.window.showErrorMessage(errMsg, openConnSettingsBtn, refreshBtn)
                .then((res) => {
                if (res === openConnSettingsBtn) {
                    ConnectionOverviewCmd_1.default(connection);
                }
                else if (res === refreshBtn) {
                    RefreshConnectionCmd_1.default(connection);
                }
            });
        }
    });
}
exports.default = toggleConnectionEnablementCmd;
//# sourceMappingURL=ToggleConnectionEnablement.js.map