"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const path = require("path");
const Logger_1 = require("../../Logger");
/**
 * Add the given project to the user's existing workspace folders.
 */
function addProjectToWorkspaceCmd(project) {
    return __awaiter(this, void 0, void 0, function* () {
        const wsFolders = vscode.workspace.workspaceFolders || [];
        if (wsFolders.some((wsf) => wsf.uri.fsPath === project.localPath.fsPath)) {
            vscode.window.showInformationMessage(`${project.localPath.fsPath} is already a workspace folder.`);
            return;
        }
        const newWsFolder = {
            uri: project.localPath,
            index: wsFolders.length,
            name: path.basename(project.localPath.fsPath),
        };
        Logger_1.default.i(`Adding ${project.localPath.fsPath} to workspace`);
        yield vscode.window.withProgress({
            location: vscode.ProgressLocation.Notification,
            cancellable: false,
            title: `Adding ${project.name} to workspace...`,
        }, () => {
            vscode.workspace.updateWorkspaceFolders(wsFolders.length, 0, newWsFolder);
            return new Promise((resolve) => {
                vscode.workspace.onDidChangeWorkspaceFolders((_e) => {
                    resolve();
                });
            });
        });
    });
}
exports.default = addProjectToWorkspaceCmd;
//# sourceMappingURL=AddToWorkspaceCmd.js.map