"use strict";
/*******************************************************************************
 * Copyright (c) 2019, 2020 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
// const STRING_NS = StringNamespaces.LOGS;
function showAllLogs(project) {
    return __awaiter(this, void 0, void 0, function* () {
        return manageLogsInner(project, "show");
    });
}
exports.showAllLogs = showAllLogs;
function hideAllLogs(project) {
    return __awaiter(this, void 0, void 0, function* () {
        return manageLogsInner(project, "hide");
    });
}
exports.hideAllLogs = hideAllLogs;
function manageLogs(project) {
    return __awaiter(this, void 0, void 0, function* () {
        return manageLogsInner(project);
    });
}
exports.manageLogs = manageLogs;
function manageLogsInner(project, all) {
    return __awaiter(this, void 0, void 0, function* () {
        // Wait for the logmanager to initialize, just in case it hasn't finished yet
        yield project.logManager.initPromise;
        const logs = project.logManager.logs;
        if (all === "hide") {
            yield project.logManager.hideAll();
            return;
        }
        if (logs.length === 0) {
            vscode.window.showWarningMessage(`${project.name} does not have any logs available at this time. Wait for the project to build, and try again.`);
            return;
        }
        if (all === "show") {
            yield project.logManager.showAll();
            return;
        }
        const options = {
            canPickMany: true,
            placeHolder: "Select the logs you wish to see in the Output view."
        };
        // https://github.com/Microsoft/vscode/issues/64014
        const logsToShow = yield vscode.window.showQuickPick(logs, options);
        if (logsToShow == null) {
            return;
        }
        yield project.logManager.showSome(logsToShow);
    });
}
//# sourceMappingURL=ManageLogsCmd.js.map