"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../../Logger");
const Commands_1 = require("../../constants/Commands");
const translator_1 = require("../../constants/strings/translator");
const StringNamespaces_1 = require("../../constants/strings/StringNamespaces");
const STRING_NS = StringNamespaces_1.default.CMD_OPEN_IN_BROWSER;
function openAppCmd(project) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!(project.state.isStarted || project.state.isStarting)) {
            vscode.window.showWarningMessage(translator_1.default.t(STRING_NS, "canOnlyOpenStartedProjects", { projectName: project.name }));
            return;
        }
        else if (project.appUrl == null) {
            Logger_1.Log.e("Project is started but has no app URL: " + project.name);
            vscode.window.showErrorMessage(translator_1.default.t(STRING_NS, "failedDetermineAppUrl", { projectName: project.name }));
            return;
        }
        const uriToOpen = project.appUrl;
        Logger_1.Log.i(`Open project ${project.name} in browser at ${uriToOpen}`);
        // vscode.window.showInformationMessage("Opening " + uriToOpen);
        vscode.commands.executeCommand(Commands_1.default.VSC_OPEN, uriToOpen);
    });
}
exports.default = openAppCmd;
//# sourceMappingURL=OpenAppCmd.js.map