"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../../Logger");
const Commands_1 = require("../../constants/Commands");
const MCUtil_1 = require("../../MCUtil");
function openAppMonitorCmd(project) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            if (!(project.state.isStarted || project.state.isStarting)) {
                vscode.window.showWarningMessage(`Cannot open application monitor - ${project.name} is not currently running.`);
                return;
            }
            if (!project.hasAppMonitor || project.appMonitorUrl == null) {
                vscode.window.showWarningMessage(getAppMetricsNotSupportedMsg(project.name));
                return;
            }
            Logger_1.default.d("Open monitor at " + project.appMonitorUrl);
            vscode.commands.executeCommand(Commands_1.default.VSC_OPEN, vscode.Uri.parse(project.appMonitorUrl));
        }
        catch (err) {
            vscode.window.showErrorMessage(MCUtil_1.default.errToString(err));
        }
    });
}
exports.default = openAppMonitorCmd;
function getAppMetricsNotSupportedMsg(projectName) {
    return `${projectName} does not support application metrics or the performance dashboard.`;
}
exports.getAppMetricsNotSupportedMsg = getAppMetricsNotSupportedMsg;
//# sourceMappingURL=OpenAppMonitor.js.map