"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const Logger_1 = require("../../Logger");
const MCUtil_1 = require("../../MCUtil");
const Endpoints_1 = require("../../constants/Endpoints");
const Commands_1 = require("../../constants/Commands");
const Constants_1 = require("../../constants/Constants");
const OpenAppMonitor_1 = require("./OpenAppMonitor");
function openPerformanceDashboard(project) {
    return __awaiter(this, void 0, void 0, function* () {
        const supportsMetrics = project.hasPerfDashboard;
        Logger_1.default.d(`${project.name} supports perfmonitor ? ${supportsMetrics}`);
        if (!supportsMetrics || !(yield project.testPingAppMonitor())) {
            vscode.window.showWarningMessage(OpenAppMonitor_1.getAppMetricsNotSupportedMsg(project.name));
            return;
        }
        try {
            const cwBaseUrl = global.isTheia ? getCodewindIngress() : project.connection.url;
            const dashboardUrl = Endpoints_1.default.getPerformanceDashboard(cwBaseUrl, project.id);
            Logger_1.default.d(`Dashboard url for ${project.name} is ${dashboardUrl}`);
            vscode.commands.executeCommand(Commands_1.default.VSC_OPEN, dashboardUrl);
        }
        catch (err) {
            vscode.window.showErrorMessage(MCUtil_1.default.errToString(err));
        }
    });
}
exports.default = openPerformanceDashboard;
const CW_INGRESS_NAME = "codewind"; // :(
function getCodewindIngress() {
    // See https://github.com/eclipse/codewind-vscode/issues/123
    // Hopefully, this is temporary. This is how we assemble the URL to the codewind ingress/route without a kube/OC client.
    // Even though this has nothing to do with the perf dashboard in particular, that is the only feature which can't use the proxy.
    const cheApiUrlStr = process.env[Constants_1.default.CHE_API_EXTERNAL_ENVVAR];
    if (!cheApiUrlStr) {
        throw new Error(`Could not determine Che API URL; ${Constants_1.default.CHE_API_EXTERNAL_ENVVAR} was not set.`);
    }
    const cheApiUrl = vscode.Uri.parse(cheApiUrlStr);
    Logger_1.default.d(`Che API URL is "${cheApiUrl}"`);
    const workspaceID = process.env[Constants_1.default.CHE_WORKSPACEID_ENVVAR];
    if (!workspaceID) {
        throw new Error(`Could not determine Che workspace ID; ${Constants_1.default.CHE_WORKSPACEID_ENVVAR} was not set.`);
    }
    // this will resolve to something like:
    // codewind-workspacebiq5onaqye4u9x3d-che-che.10.99.3.118.nip.io
    const codewindIngressAuthority = `${CW_INGRESS_NAME}-${workspaceID}-${cheApiUrl.authority}`;
    const codewindIngress = vscode.Uri.parse(`${cheApiUrl.scheme}://${codewindIngressAuthority}`);
    Logger_1.default.i(`Codewind Ingress URL is ${codewindIngress}`);
    return codewindIngress;
}
exports.getCodewindIngress = getCodewindIngress;
//# sourceMappingURL=OpenPerfDashboard.js.map