"use strict";
/*******************************************************************************
 * Copyright (c) 2019, 2020 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const rmrf = require("rimraf");
const translator_1 = require("../../constants/strings/translator");
const StringNamespaces_1 = require("../../constants/strings/StringNamespaces");
const Logger_1 = require("../../Logger");
const MCUtil_1 = require("../../MCUtil");
const ConnectionManager_1 = require("../../codewind/connection/ConnectionManager");
function removeProjectCmd(project) {
    return __awaiter(this, void 0, void 0, function* () {
        yield removeProject(project, undefined);
    });
}
exports.default = removeProjectCmd;
/**
 * @param deleteFiles - Set this to skip prompting the user, and instead just do the unbind silently.
 */
function removeProject(project, deleteFiles) {
    return __awaiter(this, void 0, void 0, function* () {
        let doDeleteProjectDir;
        if (deleteFiles == null) {
            // ask the user
            const deleteMsg = translator_1.default.t(StringNamespaces_1.default.CMD_MISC, "confirmDeleteProjectMsg", {
                projectName: project.name,
                connectionLabel: project.connection.label
            });
            const deleteBtn = translator_1.default.t(StringNamespaces_1.default.CMD_MISC, "confirmDeleteBtn", { projectName: project.name });
            const deleteRes = yield vscode.window.showInformationMessage(deleteMsg, { modal: true }, deleteBtn);
            if (deleteRes !== deleteBtn) {
                // cancelled
                return;
            }
            const projectDirPath = project.localPath.fsPath;
            const isProjectBoundElsewhere = ConnectionManager_1.default.instance.connections
                .some((conn) => conn !== project.connection && conn.hasProjectAtPath(project.localPath));
            if (isProjectBoundElsewhere) {
                // Another connection is using this project, so we cannot delete its files.
                doDeleteProjectDir = false;
            }
            else {
                // Ask user if they want to delete the files on disk too.
                const deleteDirMsg = translator_1.default.t(StringNamespaces_1.default.CMD_MISC, "alsoDeleteDirMsg", { dirPath: projectDirPath });
                const deleteDirBtn = translator_1.default.t(StringNamespaces_1.default.CMD_MISC, "alsoDeleteDirBtn");
                // const dontDeleteDirBtn = Translator.t(StringNamespaces.CMD_MISC, "dontDeleteDirBtn");
                // const deleteNeverBtn = Translator.t(StringNamespaces.CMD_MISC, "neverDeleteDirBtn");
                // const deleteAlwaysBtn = Translator.t(StringNamespaces.CMD_MISC, "alwaysDeleteDirBtn");
                const deleteDirRes = yield vscode.window.showWarningMessage(deleteDirMsg, { modal: true }, deleteDirBtn);
                doDeleteProjectDir = deleteDirRes === deleteDirBtn;
            }
        }
        else {
            doDeleteProjectDir = deleteFiles;
        }
        yield vscode.window.withProgress({
            cancellable: false,
            location: vscode.ProgressLocation.Notification,
            title: `Removing ${project.name} from ${project.connection.label}...`
        }, () => __awaiter(this, void 0, void 0, function* () {
            yield project.deleteFromCodewind(doDeleteProjectDir);
        }));
    });
}
exports.removeProject = removeProject;
function deleteProjectDir(project) {
    return __awaiter(this, void 0, void 0, function* () {
        Logger_1.default.i("Deleting project directory: " + project.localPath);
        const projectDirPath = project.localPath.fsPath;
        return new Promise((resolve, _reject) => {
            rmrf(projectDirPath, { glob: false }, (err) => {
                if (err) {
                    vscode.window.showErrorMessage(`Failed to delete ${project.name} directory: ${MCUtil_1.default.errToString(err)}`);
                }
                return resolve();
            });
        });
    });
}
exports.deleteProjectDir = deleteProjectDir;
//# sourceMappingURL=RemoveProjectCmd.js.map