"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const WebviewWrapper_1 = require("./WebviewWrapper");
const WebviewUtil_1 = require("./WebviewUtil");
const ToggleAutoInjectMetrics_1 = require("../project/ToggleAutoInjectMetrics");
const Logger_1 = require("../../Logger");
const ToggleAutoBuildCmd_1 = require("../project/ToggleAutoBuildCmd");
const ToggleEnablementCmd_1 = require("../project/ToggleEnablementCmd");
const RequestBuildCmd_1 = require("../project/RequestBuildCmd");
const RemoveProjectCmd_1 = require("../project/RemoveProjectCmd");
const ProjectOverviewPage_1 = require("./pages/ProjectOverviewPage");
const ConnectionOverviewCmd_1 = require("../connection/ConnectionOverviewCmd");
const Commands_1 = require("../../constants/Commands");
var ProjectOverviewWVMessages;
(function (ProjectOverviewWVMessages) {
    ProjectOverviewWVMessages["BUILD"] = "build";
    ProjectOverviewWVMessages["TOGGLE_AUTOBUILD"] = "toggleAutoBuild";
    ProjectOverviewWVMessages["OPEN_FOLDER"] = "openFolder";
    ProjectOverviewWVMessages["UNBIND"] = "unbind";
    ProjectOverviewWVMessages["TOGGLE_ENABLEMENT"] = "toggleEnablement";
    ProjectOverviewWVMessages["EDIT"] = "edit";
    ProjectOverviewWVMessages["TOGGLE_INJECT_METRICS"] = "toggleInjectMetrics";
})(ProjectOverviewWVMessages = exports.ProjectOverviewWVMessages || (exports.ProjectOverviewWVMessages = {}));
class ProjectOverviewPageWrapper extends WebviewWrapper_1.WebviewWrapper {
    constructor(project) {
        super(project.name, project.type.icon);
        this.project = project;
        this.handleWebviewMessage = (msg) => __awaiter(this, void 0, void 0, function* () {
            switch (msg.type) {
                case WebviewUtil_1.CommonWVMessages.OPEN_WEBLINK: {
                    WebviewUtil_1.default.openWeblink(msg.data);
                    break;
                }
                case ProjectOverviewWVMessages.OPEN_FOLDER: {
                    const targetPath = msg.data;
                    const uri = vscode.Uri.file(targetPath);
                    vscode.commands.executeCommand(Commands_1.default.VSC_REVEAL_IN_OS, uri);
                    break;
                }
                case ProjectOverviewWVMessages.TOGGLE_AUTOBUILD: {
                    ToggleAutoBuildCmd_1.default(this.project);
                    break;
                }
                case ProjectOverviewWVMessages.TOGGLE_ENABLEMENT: {
                    ToggleEnablementCmd_1.default(this.project);
                    break;
                }
                case ProjectOverviewWVMessages.BUILD: {
                    RequestBuildCmd_1.default(this.project);
                    break;
                }
                case ProjectOverviewWVMessages.UNBIND: {
                    RemoveProjectCmd_1.removeProject(this.project, undefined);
                    break;
                }
                case ProjectOverviewWVMessages.EDIT: {
                    this.project.tryOpenSettingsFile();
                    break;
                }
                case ProjectOverviewWVMessages.TOGGLE_INJECT_METRICS: {
                    ToggleAutoInjectMetrics_1.default(this.project);
                    break;
                }
                case WebviewUtil_1.CommonWVMessages.OPEN_CONNECTION:
                    ConnectionOverviewCmd_1.default(this.project.connection);
                    break;
                default: {
                    Logger_1.default.e("Received unknown event from project info webview:", msg);
                }
            }
        });
        project.onDidOpenOverviewPage(this);
        this.refresh();
    }
    generateHtml(resourceProvider) {
        return __awaiter(this, void 0, void 0, function* () {
            return ProjectOverviewPage_1.getProjectOverviewHtml(resourceProvider, this.project);
        });
    }
    onDidDispose() {
        this.project.onDidCloseOverviewPage();
    }
}
exports.default = ProjectOverviewPageWrapper;
//# sourceMappingURL=ProjectOverviewPageWrapper.js.map