"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
// import Commands from "../constants/Commands";
const Logger_1 = require("../Logger");
const Project_1 = require("../codewind/project/Project");
const Connection_1 = require("../codewind/connection/Connection");
const MCUtil_1 = require("../MCUtil");
const Configurations_1 = require("../constants/Configurations");
const LocalCodewindManager_1 = require("../codewind/connection/local/LocalCodewindManager");
const CodewindEventListener_1 = require("../codewind/connection/CodewindEventListener");
const TreeItemFactory_1 = require("./TreeItemFactory");
const ConnectionManager_1 = require("../codewind/connection/ConnectionManager");
class CodewindTreeDataProvider {
    constructor() {
        this.onTreeDataChangeEmitter = new vscode.EventEmitter();
        this.onDidChangeTreeData = this.onTreeDataChangeEmitter.event;
        /**
         * Notifies VSCode that this tree has to be refreshed.
         */
        this.refresh = (treeItem) => {
            // Log.d("refresh tree");
            this.onTreeDataChangeEmitter.fire(treeItem);
        };
        this.treeView = vscode.window.createTreeView(CodewindTreeDataProvider.VIEW_ID, { treeDataProvider: this });
        CodewindEventListener_1.default.addOnChangeListener(this.refresh);
        Logger_1.default.d("Finished constructing ProjectTree");
        if (MCUtil_1.default.isUserInCwWorkspaceOrProject() || global.isTheia) {
            if (Configurations_1.CWConfigurations.AUTO_SHOW_VIEW.get()) {
                Logger_1.default.d("Auto-expanding the Codewind view");
                // reveal the LocalCodewindManager because it is guaranteed to exist
                this.treeView.reveal(LocalCodewindManager_1.default.instance);
            }
        }
        // this.treeView.onDidChangeSelection((e) => {
        //     Log.d("Selection is now", e.selection[0]);
        // });
    }
    getTreeItem(node) {
        if (node instanceof LocalCodewindManager_1.default) {
            return TreeItemFactory_1.default.getLocalCWTI();
        }
        else if (node instanceof Project_1.default) {
            return TreeItemFactory_1.default.getProjectTI(node);
        }
        else if (node instanceof Connection_1.default) {
            return TreeItemFactory_1.default.getConnectionTI(node);
        }
        return node;
    }
    getChildren(node) {
        if (node == null) {
            return [
                LocalCodewindManager_1.default.instance,
                ...ConnectionManager_1.default.instance.remoteConnections,
            ];
        }
        else if (node instanceof Connection_1.default) {
            return TreeItemFactory_1.default.getConnectionChildren(node);
        }
        else if (node instanceof Project_1.default) {
            // projects have no children
            return [];
        }
        else if (node instanceof LocalCodewindManager_1.default) {
            const localConnection = node.localConnection;
            if (localConnection == null) {
                // codewind is turned off
                return [];
            }
            return this.getChildren(localConnection);
        }
        else {
            Logger_1.default.e("Cannot get children for unexpected item", node);
            return [];
        }
    }
    getParent(node) {
        if (node instanceof Project_1.default) {
            return node.connection;
        }
        else if (node instanceof LocalCodewindManager_1.default || node instanceof Connection_1.default) {
            // top-level items
            return undefined;
        }
        Logger_1.default.e("Unexpected TreeItem!", node);
        return undefined;
    }
}
exports.default = CodewindTreeDataProvider;
CodewindTreeDataProvider.VIEW_ID = "ext.cw.explorer"; // must match package.nls.json
//# sourceMappingURL=CodewindTree.js.map